==> xt-miniprogram-ui-1.0.13.tgz: package/libs/xt-dialog/index.js <==
// src/xt-dialog/index.js
Component({
    /**
     * 组件的属性列表
     */
    properties: {
      show:{
        type:Boolean,
        value:true
      },
      type:{
        type:String,
        value:'nomal'
      },
      title:{
        type:String,
        value:null
      },
      message:{
        type:String,
        value:''
      },
      showConfirmButton:{
        type:Boolean,
        value:true
      },
      showCancelButton:{
        type:Boolean,
        value:false
      },
      confirmButtonText:{
        type:String,
        value:'我知道了'
      },
      cancelButtonText:{
        type:String,
        value:'取消'
      },
      placeholder:{
        type:String,
        value:'请输入内容'
      },
      imageUrl:{
        type:String,
        value:null
      },
      chooiceItems:{
        type:Array,
        value:[]
      }
    },

    /**
     * 组件的初始数据
     */
    data: {
      // 输入框的值
      inpVal:'',
      // 单选框选定的值
      curChoosedItemVal: null,
    },

    lifetimes: {
      attached(){
        if(this.properties.type == 'inputText'){
          this.setData({
            inpVal: this.properties.message
          })
        }
      }
    },

    /**
     * 组件的方法列表
     */
    methods: {
      // 输入样式 - 输入框失焦
      onInputBlur(e){
        console.log('输入值',e);
        this.setData({
          inpVal: e.detail.value
        })
      },

      // 选择样式 - 选择某一项
      chooseItem(e){
        let { chooseitem } = e.currentTarget.dataset;
        this.setData({
          curChoosedItemVal: chooseitem.value
        })
        console.log('触发选择',this.data.curChoosedItemVal);
      },




      // 点击确认按钮
      confirmBtn(e){
        let { confirmtype } = e.currentTarget.dataset;
        // 常规样式&&图文样式
        if(['nomalDialog','imageTextDialog'].includes(confirmtype)){
          this.triggerEvent('confirm',{})
        }
        // 输入样式
        if(confirmtype == 'inputDialog'){
          this.triggerEvent('inputConfirm', this.data.inpVal)
        }
        // 选择样式
        if(confirmtype == 'chooseDialog'){
          if(this.data.curChoosedItemVal===null){
            wx.showToast({
              title: '请选择~',
              icon:'none',
              duration:3000
            })
            return
          }
          this.triggerEvent('chooseConfirm', this.data.curChoosedItemVal)
        }
      },
      // 点击取消按钮
      cancelBtn(){
        this.triggerEvent('cancel',{})
      }
    }
})

==> xt-miniprogram-ui-1.1.24.tgz: package/libs/xt-dialog/index.js <==
// src/xt-dialog/index.js
Component({
    /**
     * 组件的属性列表
     */
    properties: {
      show:{
        type:Boolean,
        value:true
      },
      type:{
        type:String,
        value:'nomal'
      },
      title:{
        type:String,
        value:null
      },
      message:{
        type:String,
        value:''
      },
      showConfirmButton:{
        type:Boolean,
        value:true
      },
      showCancelButton:{
        type:Boolean,
        value:false
      },
      confirmButtonText:{
        type:String,
        value:'我知道了'
      },
      cancelButtonText:{
        type:String,
        value:'取消'
      },
      placeholder:{
        type:String,
        value:'请输入内容'
      },
      imageUrl:{
        type:String,
        value:null
      },
      chooiceItems:{
        type:Array,
        value:[]
      }
    },

    /**
     * 组件的初始数据
     */
    data: {
      // 输入框的值
      inpVal:'',
      // 单选框选定的值
      curChoosedItemVal: null,
    },

    lifetimes: {
      attached(){
        if(this.properties.type == 'inputText'){
          this.setData({
            inpVal: this.properties.message
          })
        }
      }
    },

    /**
     * 组件的方法列表
     */
    methods: {
      // 输入样式 - 输入框失焦
      onInputBlur(e){
        console.log('输入值',e);
        this.setData({
          inpVal: e.detail.value
        })
      },

      // 选择样式 - 选择某一项
      chooseItem(e){
        let { chooseitem } = e.currentTarget.dataset;
        this.setData({
          curChoosedItemVal: chooseitem.value
        })
        console.log('触发选择',this.data.curChoosedItemVal);
      },




      // 点击确认按钮
      confirmBtn(e){
        let { confirmtype } = e.currentTarget.dataset;
        // 常规样式&&图文样式
        if(['nomalDialog','imageTextDialog'].includes(confirmtype)){
          this.triggerEvent('confirm',{})
        }
        // 输入样式
        if(confirmtype == 'inputDialog'){
          this.triggerEvent('confirm', this.data.inpVal)
        }
        // 选择样式
        if(confirmtype == 'chooseDialog'){
          if(this.data.curChoosedItemVal===null){
            wx.showToast({
              title: '请选择~',
              icon:'none',
              duration:3000
            })
            return
          }
          this.triggerEvent('confirm', this.data.curChoosedItemVal)
        }
      },
      // 点击取消按钮
      cancelBtn(){
        this.triggerEvent('cancel',{})
      }
    }
})
